adfMention = {
  "version": 1,
  "type": "doc",
  "content": [
    {'type': 'paragraph', 'content': [{'type': 'text', 'text': 'TEsting'}]}, 
    {'type': 'bulletList', 'content': [{'type': 'listItem', 'content': [{'type': 'paragraph', 'content': [{'type': 'text', 'text': 'test'}]}]}]}, 
    {'type': 'paragraph', 'content': []}, 
    {'type': 'orderedList', 'content': [{'type': 'listItem', 'content': [{'type': 'paragraph', 'content': [{'type': 'text', 'text': 'test 2'}]}]}]}, 
    {'type': 'paragraph', 'content': [{'type': 'mention', 'attrs': {'id': '5c1085f5c22785142f6837a5', 'text': 'Hemprasad Badgujar', 'accessLevel': ''}}, {'type': 'text', 'text': '  dfghsdfgy  sdth '}, {'type': 'mention', 'attrs': {'id': '60e41a7c1fd2a30070179f72', 'text': 'koushik.choudhury', 'accessLevel': ''}}, {'type': 'text', 'text': ' '}]}
  ]
}
 
adfAll = {
  "version": 1,
  "type": "doc",
  "content": [
    {'type': 'heading', 'attrs': {'level': 2}, 'content': [{'type': 'text', 'text': 'Testing'}, {'type': 'hardBreak'}, {'type': 'text', 'text': 'Testing 2'}]}, 
    {'type': 'heading', 'attrs': {'level': 3}, 'content': [{'type': 'text', 'text': 'Testing 3'}]}, 
    {'type': 'paragraph', 'content': [{'type': 'text', 'text': 'Testing 4'}]}, 
    {'type': 'bulletList', 'content': [{'type': 'listItem', 'content': [{'type': 'paragraph', 'content': [{'type': 'text', 'text': 'Testing 5'}]}]}, {'type': 'listItem', 'content': [{'type': 'paragraph', 'content': [{'type': 'text', 'text': 'Testing 6'}]}]}]}, 
    {'type': 'orderedList', 'content': [{'type': 'listItem', 'content': [{'type': 'paragraph', 'content': [{'type': 'text', 'text': 'Testing 7'}]}]}, {'type': 'listItem', 'content': [{'type': 'paragraph', 'content': [{'type': 'text', 'text': 'Testing 8'}]}]}, {'type': 'listItem', 'content': [{'type': 'paragraph', 'content': [{'type': 'text', 'text': 'Testing 9'}, {'type': 'hardBreak'}]}]}]}, 
    {'type': 'paragraph', 'content': [{'type': 'inlineCard', 'attrs': {'url': 'https://mckinley-rice.atlassian.net/browse/STAT-1080'}}, {'type': 'text', 'text': ' '}]}, 
    {'type': 'paragraph', 'content': [{'type': 'mention', 'attrs': {'id': '5c1085f5c22785142f6837a5', 'text': 'Hemprasad Badgujar', 'accessLevel': ''}}, {'type': 'text', 'text': '  dfghsdfgy  sdth '}, {'type': 'mention', 'attrs': {'id': '60e41a7c1fd2a30070179f72', 'text': 'koushik.choudhury', 'accessLevel': ''}}, {'type': 'text', 'text': ' why sdtysrt s ertywetry  , sertywset . aertaer '}, {'type': 'hardBreak'}, {'type': 'emoji', 'attrs': {'shortName': ':smiley:', 'id': '1f603', 'text': '😃'}}, {'type': 'text', 'text': ' '}, {'type': 'emoji', 'attrs': {'shortName': ':sweat_smile:', 'id': '1f605', 'text': '😅'}}, {'type': 'text', 'text': ' '}]}, 
    {'type': 'bulletList', 'content': [{'type': 'listItem', 'content': [{'type': 'paragraph', 'content': [{'type': 'text', 'text': 'Testing 5', 'marks': [{'type': 'strong'}]}]}]}, {'type': 'listItem', 'content': [{'type': 'paragraph', 'content': [{'type': 'text', 'text': 'Testing 6', 'marks': [{'type': 'strong'}]}]}]}]},
    {'type': 'orderedList', 'content': [{'type': 'listItem', 'content': [{'type': 'paragraph', 'content': [{'type': 'text', 'text': 'Testing 7', 'marks': [{'type': 'strong'}]}]}]}, {'type': 'listItem', 'content': [{'type': 'paragraph', 'content': [{'type': 'text', 'text': 'Testing 8', 'marks': [{'type': 'em'}]}]}]}, {'type': 'listItem', 'content': [{'type': 'paragraph', 'content': [{'type': 'text', 'text': 'Testing 9', 'marks': [{'type': 'em'}, {'type': 'strong'}]}]}]}]}
  ]
}